@@ -7,12 +7,13 @@ import pathlib
 
 import click
 
-from ... import Settings
+from ... import Fastberry
+from .plugin_maker import create_plugin
 from .shell import shell_print, unzip
 
 TEMPLATES_DIR = pathlib.Path(__file__).parents[0] / "templates"
 
-settings = Settings()
+settings = Fastberry()
 
 
 @click.command()
@@ -21,7 +22,13 @@ settings = Settings()
     type=str,
     nargs=1,
 )
-def start_app(app_name):
+@click.option(
+    "--crud/--no-crud", default=False, type=bool, help="Init with sample code."
+)
+@click.option(
+    "--plugin/--no-plugin", default=False, type=bool, help="Init <App> as a plugin."
+)
+def start_app(app_name, crud, plugin):
     """Creates a Fastberry App Directory."""
 
     # Get Path(s)
@@ -38,4 +45,9 @@ def start_app(app_name):
         shell_print(
             f"""* Starting App: "{ app_name }" ...""",
         )
-        unzip(TEMPLATES_DIR / "base_app.zip", the_dir)
+        if crud:
+            unzip(TEMPLATES_DIR / "base_app.zip", the_dir)
+        else:
+            the_dir.mkdir(parents=True, exist_ok=True)
+            if plugin:
+                create_plugin(the_dir)
